# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'RepositoryExternalConnections',
    'RepositoryUpstream',
]

@pulumi.output_type
class RepositoryExternalConnections(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "externalConnectionName":
            suggest = "external_connection_name"
        elif key == "packageFormat":
            suggest = "package_format"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RepositoryExternalConnections. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RepositoryExternalConnections.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RepositoryExternalConnections.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 external_connection_name: str,
                 package_format: Optional[str] = None,
                 status: Optional[str] = None):
        """
        :param str external_connection_name: The name of the external connection associated with a repository.
        """
        pulumi.set(__self__, "external_connection_name", external_connection_name)
        if package_format is not None:
            pulumi.set(__self__, "package_format", package_format)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="externalConnectionName")
    def external_connection_name(self) -> str:
        """
        The name of the external connection associated with a repository.
        """
        return pulumi.get(self, "external_connection_name")

    @property
    @pulumi.getter(name="packageFormat")
    def package_format(self) -> Optional[str]:
        return pulumi.get(self, "package_format")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")


@pulumi.output_type
class RepositoryUpstream(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "repositoryName":
            suggest = "repository_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RepositoryUpstream. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RepositoryUpstream.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RepositoryUpstream.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 repository_name: str):
        """
        :param str repository_name: The name of an upstream repository.
        """
        pulumi.set(__self__, "repository_name", repository_name)

    @property
    @pulumi.getter(name="repositoryName")
    def repository_name(self) -> str:
        """
        The name of an upstream repository.
        """
        return pulumi.get(self, "repository_name")


